unit UnitMain;

interface

uses
  SysUtils, Types, UITypes, Classes, Variants, FMX_Types, FMX_Controls, FMX_Forms,
  FMX_Dialogs, FMX_Objects, FMX_Effects, FMXTee_Engine, FMXTee_Series,
  FMXTee_Procs, FMXTee_Chart, FMX_Layouts, FMX_ListBox, FMX_TabControl,
  FMXTee_Editor_Functions_Gallery, FMXTee_Tools_Gallery;

type
  TMainForm = class(TForm)
    Text1: TText;
    Image1: TImage;
    Chart1: TChart;
    Series1: TPieSeries;
    InnerGlowEffect1: TInnerGlowEffect;
    GlowEffect1: TGlowEffect;
    ShadowEffect1: TShadowEffect;
    Layout1: TLayout;
    Layout2: TLayout;
    CheckBox1: TCheckBox;
    TabControl1: TTabControl;
    TabItem1: TTabItem;
    ListSeries: TListBox;
    TabItem2: TTabItem;
    Splitter1: TSplitter;
    TabItem3: TTabItem;
    procedure Image1Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure ListSeriesChange(Sender: TObject);
    procedure CheckBox1Change(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure Text1Click(Sender: TObject);
    procedure Chart1ClickSeries(Sender: TCustomChart; Series: TChartSeries;
      ValueIndex: Integer; Button: TMouseButton; Shift: TShiftState; X,
      Y: Integer);
    procedure TabControl1Change(Sender: TObject);
  private
    { Private declarations }

    Funcs : TFunctionsGallery;
    Tools : TToolsGallery;

    procedure ChangeSeries(AClass:TChartSeriesClass; AItem:TListBoxItem);
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.lfm}

uses
  FMXTee_About, FMXTee_Editor_Pro, DemoBar, FMXTee_Editor_Chart,
  FMXTee_Series_World, FMXTee_Editor_Stroke;

procedure TMainForm.Button1Click(Sender: TObject);
begin
  with TDemoBarSeries.Create(Self) do
       Show;
end;

procedure TMainForm.Chart1ClickSeries(Sender: TCustomChart;
  Series: TChartSeries; ValueIndex: Integer; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
  TChartEditForm.Edit(Self,Chart1);
end;

procedure TMainForm.CheckBox1Change(Sender: TObject);
begin
  Chart1.View3D:=CheckBox1.IsChecked;
end;

procedure TMainForm.FormCreate(Sender: TObject);
var
  t: Integer;
  i: TListBoxItem;
  s: String;
begin
  Series1.FillSampleValues;

  ListSeries.Clear;

  for t := 0 to TeeSeriesTypes.Count-1 do
     if TeeSeriesTypes[t].FunctionClass=nil then
     begin
       i:=TListBoxItem.Create(Self);
       i.Data:=TObject(TeeSeriesTypes[t].SeriesClass);

       s:=StringReplace(TeeSeriesTypes[t].Description^,#13,' ',[rfReplaceAll]);
       i.Text:=s;

       i.Tag:=TeeSeriesTypes[t].SubIndex;

       ListSeries.AddObject(i);
     end;

  ListSeries.Sorted:=True;

  TabControl1.ActiveTab:=TabItem1;
end;

procedure TMainForm.FormResize(Sender: TObject);
begin
  if (Width>Height) and (Layout2.Align<>TAlignLayout.alRight) then
  begin
    Layout2.Align:=TAlignLayout.alRight;
    Layout1.Align:=TAlignLayout.alClient;

    if TabControl1.ActiveTab=TabItem1 then
       Layout2.Width:=100
    else
       Layout2.Width:=300;

    Splitter1.Align:=TAlignLayout.alRight;
    Realign;
  end
  else
  if (Width<=Height) and (Layout2.Align<>TAlignLayout.alClient) then
  begin
    Layout1.Align:=TAlignLayout.alTop;
    Layout2.Align:=TAlignLayout.alClient;
    Layout1.Height:=288;
    Splitter1.Align:=TAlignLayout.alBottom;
    Realign;
  end;
end;

procedure TMainForm.Image1Click(Sender: TObject);
begin
  TeeGotoURL(Handle, 'http://www.steema.com');
end;

procedure TMainForm.ChangeSeries(AClass:TChartSeriesClass; AItem:TListBoxItem);
var c : TChartSeries;
begin
  Chart1.FreeAllSeries;

  Chart1.View3D:=CheckBox1.IsChecked;

  c:=AClass.Create(Self);

  if c is TWorldSeries then
  begin
    if Assigned(AItem) then
       TWorldSeries(c).Map:=TWorldMap(AItem.Tag);

    Chart1.View3D:=False;
  end;

  c.FillSampleValues;

  c.ParentChart:=Chart1;

  Chart1.View3DOptions.Orthogonal:=True;
end;

procedure TMainForm.ListSeriesChange(Sender: TObject);
var s : TListBoxItem;
begin
  s:=ListSeries.Selected;

  if Assigned(s) then
     ChangeSeries(TChartSeriesClass(s.Data),s);
end;

procedure TMainForm.TabControl1Change(Sender: TObject);
begin
  if TabControl1.ActiveTab=TabItem2 then
  begin
    if not Assigned(TabItem2.TagObject) then
    begin
      Funcs:=TFunctionsGallery.Create(Self);
      Funcs.PanelButtons.Visible:=False;
      EmbeddForm(Funcs, TabItem2);
      TabItem2.TagObject:=Funcs;
    end;
  end
  else
  if TabControl1.ActiveTab=TabItem3 then
  begin
    if not Assigned(TabItem3.TagObject) then
    begin
      Tools:=TToolsGallery.CreateEditor(Self);
      Tools.PanelButtons.Visible:=False;
      EmbeddForm(Tools, TabItem3);
      TabItem3.TagObject:=Tools;
      Tools.Activate;
    end;
  end;
end;

procedure TMainForm.Text1Click(Sender: TObject);
begin
  with TFormAbout.Create(Self) do
  try
    ShowModal;
  finally
    Free;
  end;
end;

end.
